@@ -1,9 +1,7 @@
 #! /usr/bin/env python
 
-# Author: David Goodger
-# Contact: goodger@users.sourceforge.net
-# Revision: $Revision: 3129 $
-# Date: $Date: 2005-03-26 17:21:28 +0100 (Sat, 26 Mar 2005) $
+# $Id: test_peps.py 4564 2006-05-21 20:44:42Z wiemann $
+# Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -54,7 +52,7 @@ A "References" section should be generated.
     <section ids="id1">
         <title>
             References
-        <footnote auto="1" ids="id2" names="TARGET_NOTE: id2">
+        <footnote auto="1" ids="id2" names="TARGET_NOTE:\ id2">
             <paragraph>
                 <reference refuri="http://www.example.org">
                     http://www.example.org
