@@ -1,9 +1,7 @@
 #!/usr/bin/env python
 
-# Author: Felix Wiemann
-# Contact: Felix_Wiemann@ososo.de
-# Revision: $Revision: 3129 $
-# Date: $Date: 2005-03-26 17:21:28 +0100 (Sat, 26 Mar 2005) $
+# $Id: test_pseudoxml.py 5174 2007-05-31 00:01:52Z wiemann $
+# Author: Lea Wiemann <LeWiemann@gmail.com>
 # Copyright: This module has been placed in the public domain.
 
 """
@@ -22,33 +20,28 @@ totest = {}
 totest['basic'] = [
 # input
 ["""\
-This is the title
-=================
-
 This is a paragraph.
 
 ----------
 
 This is another paragraph.
 
-A subsection
-------------
+A Section
+---------
 
 Foo.
 """,
 # output
 """\
-<document ids="this-is-the-title" names="this is the title" source="<string>">
-    <title>
-        This is the title
+<document source="<string>">
     <paragraph>
         This is a paragraph.
     <transition>
     <paragraph>
         This is another paragraph.
-    <section ids="a-subsection" names="a subsection">
+    <section ids="a-section" names="a\ section">
         <title>
-            A subsection
+            A Section
         <paragraph>
             Foo.
 """]
